# Generated by roxygen2: do not edit by hand

S3method(cips_test,dcce_fit)
S3method(cips_test,default)
S3method(cips_test,matrix)
S3method(coef,dcce_fit)
S3method(confint,dcce_fit)
S3method(fitted,dcce_fit)
S3method(glance,dcce_fit)
S3method(panel_ur_test,default)
S3method(panel_ur_test,matrix)
S3method(pcd_test,data.frame)
S3method(pcd_test,dcce_fit)
S3method(pcd_test,default)
S3method(pcd_test,matrix)
S3method(plot,dcce_fit)
S3method(plot,dcce_irf)
S3method(plot,dcce_rolling)
S3method(predict,dcce_fit)
S3method(print,dcce_boot)
S3method(print,dcce_break)
S3method(print,dcce_cd)
S3method(print,dcce_cips)
S3method(print,dcce_cointegration)
S3method(print,dcce_cointegration_extra)
S3method(print,dcce_csd)
S3method(print,dcce_fit)
S3method(print,dcce_granger)
S3method(print,dcce_hausman)
S3method(print,dcce_ic)
S3method(print,dcce_irf)
S3method(print,dcce_rank)
S3method(print,dcce_rolling)
S3method(print,dcce_swamy)
S3method(print,dcce_unit_root)
S3method(print,dcce_workflow)
S3method(residuals,dcce_fit)
S3method(summary,dcce_fit)
S3method(tidy,dcce_fit)
S3method(update,dcce_fit)
S3method(vcov,dcce_fit)
export(D)
export(L)
export(Lrange)
export(bootstrap)
export(cips_test)
export(cointegration_test)
export(csd_exp)
export(dcce)
export(dcce_bootstrap)
export(dcce_rolling)
export(dcce_workflow)
export(granger_test)
export(hausman_test)
export(ic)
export(irf)
export(panel_coint_test)
export(panel_ur_test)
export(pcd_test)
export(rank_condition)
export(structural_break_test)
export(swamy_test)
importFrom(Matrix,rankMatrix)
importFrom(Rcpp,sourceCpp)
importFrom(cli,cli_abort)
importFrom(cli,cli_inform)
importFrom(cli,cli_warn)
importFrom(collapse,GRP)
importFrom(collapse,fmean)
importFrom(generics,glance)
importFrom(generics,tidy)
importFrom(rlang,abort)
importFrom(rlang,arg_match)
importFrom(rlang,check_required)
importFrom(rlang,f_rhs)
importFrom(rlang,inform)
importFrom(rlang,warn)
importFrom(sandwich,NeweyWest)
importFrom(stats,coef)
importFrom(stats,complete.cases)
importFrom(stats,cor)
importFrom(stats,dnorm)
importFrom(stats,fitted)
importFrom(stats,lm)
importFrom(stats,model.matrix)
importFrom(stats,na.omit)
importFrom(stats,pnorm)
importFrom(stats,qnorm)
importFrom(stats,quantile)
importFrom(stats,residuals)
importFrom(stats,sd)
importFrom(stats,setNames)
importFrom(stats,terms)
importFrom(stats,var)
importFrom(stats,vcov)
importFrom(tibble,as_tibble)
importFrom(tibble,tibble)
useDynLib(dcce, .registration = TRUE)
