#' @keywords internal
#' @aliases dcce-package
"_PACKAGE"

#' @importFrom stats coef fitted lm model.matrix pnorm qnorm residuals vcov
#'   dnorm sd var cor na.omit complete.cases setNames quantile terms
#' @importFrom Matrix rankMatrix
#' @importFrom collapse fmean GRP
#' @importFrom sandwich NeweyWest
#' @importFrom generics tidy glance
#' @importFrom rlang abort warn inform check_required arg_match f_rhs
#' @importFrom cli cli_abort cli_warn cli_inform
#' @importFrom tibble tibble as_tibble
#' @importFrom Rcpp sourceCpp
#' @useDynLib dcce, .registration = TRUE
NULL
