# Generated by using Rcpp::compileAttributes() -> do not edit by hand
# Generator token: 10BE3573-1514-4C36-9D1C-5A225CD40393

.unit_ols_cpp <- function(X, y) {
    .Call(`_dcce_unit_ols_cpp`, X, y)
}

.batch_ols_cpp <- function(panel_list) {
    .Call(`_dcce_batch_ols_cpp`, panel_list)
}

