% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/est_mg.R
\name{mg_estimator}
\alias{mg_estimator}
\title{Mean Group Estimator Internals}
\description{
Internal functions for the Pesaran & Smith (1995) Mean Group estimator.
}
\keyword{internal}
