% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/panel_utils.R
\name{.check_balance}
\alias{.check_balance}
\title{Check panel balance}
\usage{
.check_balance(panel)
}
\arguments{
\item{panel}{A panel data.frame from \code{.make_panel()}.}
}
\value{
A list with elements \code{is_balanced}, \code{T_i} (named vector of per-unit
time periods), \code{T_min}, \code{T_max}, \code{T_bar}, \code{N}.
}
\description{
Check panel balance
}
\keyword{internal}
