% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/pcd_test.R
\name{.cd_pesaran}
\alias{.cd_pesaran}
\title{Pesaran (2015) CD statistic}
\usage{
.cd_pesaran(rho_ij, N, T_val, em)
}
\description{
Pesaran (2015) CD statistic
}
\keyword{internal}
