% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/est_csardl.R
\name{.csardl_mg_lr}
\alias{.csardl_mg_lr}
\title{Aggregate unit-level long-run and adjustment results to the MG level}
\usage{
.csardl_mg_lr(unit_lr)
}
\arguments{
\item{unit_lr}{A list of unit-level results from \code{.csardl_unit_lr()}.}
}
\value{
A list with MG long-run coefficients, MG variance, MG adjustment
speed, and an inverse-variance weighted pooled long-run estimate (used
by PMG).
}
\description{
Aggregate unit-level long-run and adjustment results to the MG level
}
\keyword{internal}
