% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/est_cce.R
\name{cce_estimator}
\alias{cce_estimator}
\title{Static CCE Estimator Internals}
\description{
Internal functions for the Pesaran (2006) Common Correlated Effects
estimator (both Mean Group and Pooled variants).
}
\keyword{internal}
