% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/pcd_test.R
\name{.cd_pea}
\alias{.cd_pea}
\title{PEA (Fan et al. 2015) power-enhanced statistic}
\usage{
.cd_pea(rho_ij, N, T_val, em)
}
\description{
PEA (Fan et al. 2015) power-enhanced statistic
}
\keyword{internal}
