% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/pcd_test.R
\name{.cd_weighted}
\alias{.cd_weighted}
\title{CDw (Juodis & Reese 2022) weighted statistic}
\usage{
.cd_weighted(em, n_reps)
}
\description{
CDw (Juodis & Reese 2022) weighted statistic
}
\keyword{internal}
