% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/est_mg.R
\name{.dcce_cpp_available}
\alias{.dcce_cpp_available}
\title{Check whether the compiled C++ unit-OLS routines are available}
\usage{
.dcce_cpp_available()
}
\description{
Check whether the compiled C++ unit-OLS routines are available
}
\keyword{internal}
