% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/methods_dcce_fit.R
\name{update.dcce_fit}
\alias{update.dcce_fit}
\title{Update a dcce_fit object}
\usage{
\method{update}{dcce_fit}(object, formula. = NULL, ..., evaluate = TRUE)
}
\arguments{
\item{object}{A \code{dcce_fit} object.}

\item{formula.}{Optional replacement formula (use \code{.} to keep
existing parts).}

\item{...}{Additional arguments passed to \code{dcce()} to override
the original call.}

\item{evaluate}{Logical: evaluate the updated call? Default \code{TRUE}.}
}
\value{
An updated \code{dcce_fit} object (if \code{evaluate = TRUE}) or
an unevaluated call.
}
\description{
Update a dcce_fit object
}
