% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/cointegration_extra.R
\name{.pedroni_core}
\alias{.pedroni_core}
\title{Pedroni group-mean statistics}
\usage{
.pedroni_core(resid_list, lags)
}
\description{
Pedroni group-mean statistics
}
\keyword{internal}
