% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/dcce.R
\name{.resolve_cr_vars}
\alias{.resolve_cr_vars}
\title{Resolve cross-sectional average variables}
\usage{
.resolve_cr_vars(cr_formula, y_name, x_names, panel)
}
\arguments{
\item{cr_formula}{A one-sided formula for CSA variables.}

\item{y_name}{Character: dependent variable name.}

\item{x_names}{Character: regressor names.}

\item{panel}{A panel data.frame.}
}
\value{
Character vector of variable names to compute CSAs for.
}
\description{
Resolve cross-sectional average variables
}
\keyword{internal}
