% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/cointegration_extra.R
\name{.kao_core}
\alias{.kao_core}
\title{Kao ADF statistic}
\usage{
.kao_core(resid_list, lags)
}
\description{
Kao ADF statistic
}
\keyword{internal}
