% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/pcd_test.R
\name{.validate_cd_tests}
\alias{.validate_cd_tests}
\title{Validate CD test names}
\usage{
.validate_cd_tests(test)
}
\description{
Validate CD test names
}
\keyword{internal}
