% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/dcce.R
\name{.parse_dcce_formula}
\alias{.parse_dcce_formula}
\title{Parse dcce formula}
\usage{
.parse_dcce_formula(formula, panel, unit_var, time_var)
}
\arguments{
\item{formula}{A formula.}

\item{panel}{A panel data.frame.}

\item{unit_var}{Character: unit variable name.}

\item{time_var}{Character: time variable name.}
}
\value{
A list with \code{y_name} and \code{x_names}.
}
\description{
Extracts the dependent variable name and regressor names from the formula.
Evaluates \code{L()}, \code{D()}, \code{Lrange()} calls by applying them panel-aware
and adding the resulting columns to the panel.
}
\keyword{internal}
