% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/csa_utils.R
\name{.get_csa_colnames}
\alias{.get_csa_colnames}
\title{Get CSA column names}
\usage{
.get_csa_colnames(panel)
}
\arguments{
\item{panel}{A panel data.frame with CSA columns.}
}
\value{
Character vector of CSA column names.
}
\description{
Returns all column names matching the CSA naming convention.
}
\keyword{internal}
