% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/pcd_test.R
\name{.pcd_test_core}
\alias{.pcd_test_core}
\title{Core computation for pcd_test}
\usage{
.pcd_test_core(em, N, test, n_reps, n_pca)
}
\description{
Core computation for pcd_test
}
\keyword{internal}
