% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/unit_root_extra.R
\name{.panel_ur_core}
\alias{.panel_ur_core}
\title{Core IPS / LLC computation}
\usage{
.panel_ur_core(y_mat, test, lags, trend)
}
\description{
Core IPS / LLC computation
}
\keyword{internal}
