% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/workflow.R
\name{.build_suggested_call}
\alias{.build_suggested_call}
\title{Internal: build a suggested dcce() call string}
\usage{
.build_suggested_call(
  rec_model,
  unit_index,
  time_index,
  y_name,
  x_names,
  rec_lags,
  data_name
)
}
\description{
Internal: build a suggested dcce() call string
}
\keyword{internal}
