% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/methods_dcce_fit.R
\name{dcce_fit_methods}
\alias{dcce_fit_methods}
\title{S3 Methods for dcce_fit Objects}
\description{
S3 Methods for dcce_fit Objects
}
\keyword{internal}
