% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/est_mg.R
\name{.mg_aggregate}
\alias{.mg_aggregate}
\title{Mean Group aggregation}
\usage{
.mg_aggregate(coef_list)
}
\arguments{
\item{coef_list}{A list of numeric coefficient vectors (one per unit).}
}
\value{
Numeric vector: Mean Group coefficient.
}
\description{
Computes the unweighted average of unit-level coefficient vectors.
}
\keyword{internal}
