% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/absorb.R
\name{.absorb_resolve}
\alias{.absorb_resolve}
\title{Resolve absorb argument to a list of grouping vectors}
\usage{
.absorb_resolve(absorb, panel)
}
\arguments{
\item{absorb}{Either \code{NULL}, a character vector of column names,
or a one-sided formula like \code{~ industry + year}.}

\item{panel}{A panel data.frame.}
}
\value{
A named list of grouping factors (one per variable) or
\code{NULL} if no absorb requested.
}
\description{
Resolve absorb argument to a list of grouping vectors
}
\keyword{internal}
