% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/est_mg.R
\name{.mg_variance}
\alias{.mg_variance}
\title{Mean Group variance}
\usage{
.mg_variance(coef_list, b_mg)
}
\arguments{
\item{coef_list}{A list of numeric coefficient vectors.}

\item{b_mg}{Numeric vector: the MG coefficient (from \code{.mg_aggregate()}).}
}
\value{
A variance-covariance matrix.
}
\description{
Non-parametric variance estimator for the MG coefficient:
\verb{V = (1/N^2) * sum_i (b_i - b_mg)(b_i - b_mg)'}
}
\keyword{internal}
