% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/est_pmg.R
\name{.pmg_postprocess}
\alias{.pmg_postprocess}
\title{Post-process a PMG fit}
\usage{
.pmg_postprocess(fit)
}
\arguments{
\item{fit}{A \code{dcce_fit} object with CS-ARDL post-processing.}
}
\value{
Augmented fit object.
}
\description{
Takes a fit that has already been run through \code{.csardl_postprocess()}
and overrides the long-run block with the pooled PMG estimates. The
adjustment speed remains the MG average.
}
\keyword{internal}
