% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/dcce.R
\name{.extract_base_vars}
\alias{.extract_base_vars}
\title{Extract base variable names}
\usage{
.extract_base_vars(var_names, panel)
}
\arguments{
\item{var_names}{Character vector of variable names.}

\item{panel}{A panel data.frame.}
}
\value{
Character vector of base variable names that exist in panel.
}
\description{
Given potentially transformed names like "L(y,1)" or "D(x,1)",
extract the underlying variable names.
}
\keyword{internal}
