% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/dcce.R
\name{.build_unit_X}
\alias{.build_unit_X}
\title{Build the regressor matrix for a single unit}
\usage{
.build_unit_X(panel, idx, x_names, csa_colnames, include_constant, unit_trend)
}
\arguments{
\item{panel}{Panel data.frame.}

\item{idx}{Integer indices for this unit.}

\item{x_names}{Character: structural regressor names.}

\item{csa_colnames}{Character: CSA column names (or NULL).}

\item{include_constant}{Logical: include intercept?}

\item{unit_trend}{Logical: include time trend?}
}
\value{
A numeric matrix.
}
\description{
Build the regressor matrix for a single unit
}
\keyword{internal}
