% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/cointegration.R
\name{.westerlund_pvalue}
\alias{.westerlund_pvalue}
\title{Approximate asymptotic p-value for a Westerlund statistic}
\usage{
.westerlund_pvalue(stat, test_name)
}
\description{
Uses critical values from Westerlund (2007, Table 3). For values more
extreme than the 1\% critical value, p_value is clamped to 0.001. For
values less extreme than the 10\% critical value, p_value is set to 0.5.
Linear interpolation between tabulated critical values is used
in-between. All statistics have a large-negative rejection region.
}
\keyword{internal}
