% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/cips.R
\name{.cips_core}
\alias{.cips_core}
\title{Core CIPS computation}
\usage{
.cips_core(y_mat, lags = 0L, trend = FALSE)
}
\description{
Core CIPS computation
}
\keyword{internal}
